==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/en_GB.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comments",
    "Unknown user" : "Unknown user",
    "New comment …" : "New comment …",
    "Delete comment" : "Delete comment",
    "Post" : "Post",
    "Cancel" : "Cancel",
    "Edit comment" : "Edit comment",
    "[Deleted user]" : "[Deleted user]",
    "No comments yet, start the conversation!" : "No comments yet, start the conversation!",
    "More comments …" : "More comments …",
    "Save" : "Save",
    "Allowed characters {count} of {max}" : "Allowed characters: {count} of {max}",
    "Error occurred while retrieving comment with id {id}" : "Error occurred while retrieving comment with id {id}",
    "Error occurred while updating comment with id {id}" : "Error occurred while updating comment with id {id}",
    "Error occurred while posting comment" : "Error occurred while posting comment",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"],
    "Comment" : "Comment",
    "You commented" : "You commented",
    "%1$s commented" : "%1$s commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "A (now) deleted user mentioned you in a comment on “{file}”",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentioned you in a comment on “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentioned you in a comment on “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/en_GB.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comments",
    "Unknown user" : "Unknown user",
    "New comment …" : "New comment …",
    "Delete comment" : "Delete comment",
    "Post" : "Post",
    "Cancel" : "Cancel",
    "Edit comment" : "Edit comment",
    "[Deleted user]" : "[Deleted user]",
    "No comments yet, start the conversation!" : "No comments yet, start the conversation!",
    "More comments …" : "More comments …",
    "Save" : "Save",
    "Allowed characters {count} of {max}" : "Allowed characters: {count} of {max}",
    "Error occurred while retrieving comment with id {id}" : "Error occurred while retrieving comment with id {id}",
    "Error occurred while updating comment with id {id}" : "Error occurred while updating comment with id {id}",
    "Error occurred while posting comment" : "Error occurred while posting comment",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"],
    "Comment" : "Comment",
    "You commented" : "You commented",
    "%1$s commented" : "%1$s commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "You were mentioned on “%s”, in a comment by a user that has since been deleted",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "You were mentioned on “{file}”, in a comment by a user that has since been deleted",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s mentioned you in a comment on “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} mentioned you in a comment on “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "A (now) deleted user mentioned you in a comment on “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "A (now) deleted user mentioned you in a comment on “{file}”"
},
"nplurals=2; plural=(n != 1);");
